==> zio-aws-mgn_2.13-5.17.155.1-sources.jar: zio/aws/mgn/model/LifeCycleLastCutoverInitiated.scala <==
package zio.aws.mgn.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mgn.model.primitives.{JobID, ISO8601DatetimeString}
import scala.jdk.CollectionConverters._
final case class LifeCycleLastCutoverInitiated(
    apiCallDateTime: Option[ISO8601DatetimeString] = None,
    jobID: Option[JobID] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated = {
    import LifeCycleLastCutoverInitiated.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated
      .builder()
      .optionallyWith(
        apiCallDateTime.map(value =>
          ISO8601DatetimeString.unwrap(value): java.lang.String
        )
      )(_.apiCallDateTime)
      .optionallyWith(
        jobID.map(value => JobID.unwrap(value): java.lang.String)
      )(_.jobID)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.LifeCycleLastCutoverInitiated.ReadOnly =
    zio.aws.mgn.model.LifeCycleLastCutoverInitiated.wrap(buildAwsValue())
}
object LifeCycleLastCutoverInitiated {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.LifeCycleLastCutoverInitiated =
      zio.aws.mgn.model.LifeCycleLastCutoverInitiated(
        apiCallDateTime.map(value => value),
        jobID.map(value => value)
      )
    def apiCallDateTime: Option[ISO8601DatetimeString]
    def jobID: Option[JobID]
    def getApiCallDateTime: ZIO[Any, AwsError, ISO8601DatetimeString] =
      AwsError.unwrapOptionField("apiCallDateTime", apiCallDateTime)
    def getJobID: ZIO[Any, AwsError, JobID] =
      AwsError.unwrapOptionField("jobID", jobID)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated
  ) extends zio.aws.mgn.model.LifeCycleLastCutoverInitiated.ReadOnly {
    override val apiCallDateTime: Option[ISO8601DatetimeString] = scala
      .Option(impl.apiCallDateTime())
      .map(value => zio.aws.mgn.model.primitives.ISO8601DatetimeString(value))
    override val jobID: Option[JobID] = scala
      .Option(impl.jobID())
      .map(value => zio.aws.mgn.model.primitives.JobID(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated
  ): zio.aws.mgn.model.LifeCycleLastCutoverInitiated.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mgn_2.13-5.17.195.2-sources.jar: zio/aws/mgn/model/LifeCycleLastCutoverInitiated.scala <==
package zio.aws.mgn.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.mgn.model.primitives.{JobID, ISO8601DatetimeString}
import scala.jdk.CollectionConverters._
final case class LifeCycleLastCutoverInitiated(
    apiCallDateTime: Optional[ISO8601DatetimeString] = Optional.Absent,
    jobID: Optional[JobID] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated = {
    import LifeCycleLastCutoverInitiated.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated
      .builder()
      .optionallyWith(
        apiCallDateTime.map(value =>
          ISO8601DatetimeString.unwrap(value): java.lang.String
        )
      )(_.apiCallDateTime)
      .optionallyWith(
        jobID.map(value => JobID.unwrap(value): java.lang.String)
      )(_.jobID)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.LifeCycleLastCutoverInitiated.ReadOnly =
    zio.aws.mgn.model.LifeCycleLastCutoverInitiated.wrap(buildAwsValue())
}
object LifeCycleLastCutoverInitiated {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.LifeCycleLastCutoverInitiated =
      zio.aws.mgn.model.LifeCycleLastCutoverInitiated(
        apiCallDateTime.map(value => value),
        jobID.map(value => value)
      )
    def apiCallDateTime: Optional[ISO8601DatetimeString]
    def jobID: Optional[JobID]
    def getApiCallDateTime: ZIO[Any, AwsError, ISO8601DatetimeString] =
      AwsError.unwrapOptionField("apiCallDateTime", apiCallDateTime)
    def getJobID: ZIO[Any, AwsError, JobID] =
      AwsError.unwrapOptionField("jobID", jobID)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated
  ) extends zio.aws.mgn.model.LifeCycleLastCutoverInitiated.ReadOnly {
    override val apiCallDateTime: Optional[ISO8601DatetimeString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.apiCallDateTime())
        .map(value => zio.aws.mgn.model.primitives.ISO8601DatetimeString(value))
    override val jobID: Optional[JobID] = zio.aws.core.internal
      .optionalFromNullable(impl.jobID())
      .map(value => zio.aws.mgn.model.primitives.JobID(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.LifeCycleLastCutoverInitiated
  ): zio.aws.mgn.model.LifeCycleLastCutoverInitiated.ReadOnly = new Wrapper(
    impl
  )
}
